@@ -9,7 +9,7 @@
 from functools import wraps
 import os
 class IsPycharmRun:
-    def __init__(self, deviceUrl, logDir):
+    def __init__(self, deviceUrl, logDir=None):
         self.deviceUrl = deviceUrl
         self.logDir = logDir
 
@@ -18,7 +18,7 @@ class IsPycharmRun:
         def wrapped_function(*args):
             if self.isPycharmRun():
                 print(func.__name__ + " was called")
-                return func(basedir=args[0], devices=self.deviceUrl)
+                return func(basedir=args[0], devices=self.deviceUrl, logdir=self.logDir)
             else:
                 return func(*args)
         return wrapped_function
